%define debug_package %{nil}

#
# spec file for package Zeek
#
# Copyright (c) 1995-2014 The Regents of the University of California
# through the Lawrence Berkeley National Laboratory and the
# International Computer Science Institute. All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# (1) Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
# (2) Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# (3) Neither the name of the University of California, Lawrence Berkeley
#     National Laboratory, U.S. Dept. of Energy, International Computer
#     Science Institute, nor the names of contributors may be used to endorse
#     or promote products derived from this software without specific prior
#     written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#
# Note that some files in the distribution may carry their own copyright
# notices.
Name:           zeek
Version:        3.0.7
Release:        0%{?dist}
Summary:        Zeek is a powerful framework for network analysis and security monitoring
Group:          Productivity/Networking/Diagnostic

License:        BSD-3-Clause
URL:            http://zeek.org
Source0:        http://www.zeek.org/downloads/%{name}-%{version}.tar.gz
Patch0:         install-symlink-old-cmake.patch
%if 0%{?centos} == 6 || 0%{?scientificlinux} == 6 || 0%{?rhel} == 5
Patch1:         cmake-2.6.patch
%endif
%if 0%{?fedora} >= 30 || 0%{?centos} == 8 || 0%{?scientificlinux} == 8 || 0%{?rhel} == 5
Patch1:         %{name}-%{version}-patch-001
%endif
Requires:       %{name}-core = %{version}
Requires:       %{name}ctl = %{version}
Requires(pre):  /usr/sbin/groupadd, /usr/bin/getent

%if %{defined rhel}
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%endif

%define _prefix /opt/%{name}
%define _sysconfdir %{_prefix}/etc
%define _libdir %{_prefix}/lib
%define _mandir %{_prefix}/share/man

%if 0%{?suse}
%define __cmake /usr/bin/cmake
%endif

%description
Zeek is a powerful network analysis framework that is much different from the
typical IDS you may know.  While focusing on network security monitoring, Zeek
provides a comprehensive platform for more general network traffic analysis as
well. Well grounded in more than 15 years of research, Zeek has successfully
bridged the traditional gap between academia and operations since its
inception. Today, it is relied upon operationally in particular by many
scientific environments for securing their cyberinfrastructure. Zeek's user
community includes major universities, research labs, supercomputing centers,
and open-science communities.

%package -n %{name}-core
Summary:        The core bro installation without broctl
Group:          Productivity/Networking/Diagnostic
BuildRequires: flex bison cmake openssl-devel zlib-devel python2-devel swig gcc-c++
BuildRequires: libpcap-devel
%if 0%{?sle} >= 150000 || 0%{?suse} >= 1550
BuildRequires: python3
%endif

%description -n %{name}-core
Zeek is a powerful network analysis framework that is much different from the
typical IDS you may know.  While focusing on network security monitoring, Zeek
provides a comprehensive platform for more general network traffic analysis as
well. Well grounded in more than 15 years of research, Zeek has successfully
bridged the traditional gap between academia and operations since its
inception. Today, it is relied upon operationally in particular by many
scientific environments for securing their cyberinfrastructure. Zeek's user
community includes major universities, research labs, supercomputing centers,
and open-science communities.

%package -n %{name}-devel
Summary:        Development files for Zeek
Group:          Productivity/Networking/Diagnostic
Requires:       %{name}-libcaf-devel = %{version}
Requires:       libbroker-devel = %{version}

%description -n %{name}-devel
Development files for Zeek; these files are needed when building binary packages
for Zeek.

%package -n %{name}-libcaf-devel
Summary:        C++ actor framework development files
Group:          System/Libraries

%description -n %{name}-libcaf-devel
CAF is an open source C++11 actor model implementation featuring lightweight &
fast actor implementations, pattern matching for messages, network transparent
messaging, and more.
This package bundles the library files and headers that were used during the Zeek
build process; they may be needed when building packages for Zeek.

%package -n libbroker-devel
Summary:        Development files for Zeek's Messaging Library
Group:          System/Libraries

%description -n libbroker-devel
Zeek library implements Zeek's high-level communication patterns.
This package bundles the library files and headers that were used during the Zeek
build process; they may be needed when building packages for Zeek.

%package -n %{name}ctl
Summary:        Zeek Control
Group:          Productivity/Networking/Diagnostic
%if 0%{?sle} == 150000
Requires: python3
%else
Requires:       python
%endif
Requires:       %{name}-core = %{version}
%if 0%{?suse}
Requires:       python-curses
%endif

%description -n %{name}ctl
ZeekControl is Zeek's interactive shell for operating Zeek installations.

%pre
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%pre -n %{name}-core
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%pre -n %{name}-devel
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%pre -n %{name}ctl
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%pre -n %{name}-libcaf-devel
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%pre -n libbroker-devel
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}

%prep
%setup -n %{name}-%{version} -q
# some platforms do in-source builds when using cmake. I don't really care, so just patch the error out.
find ./ -name "ProhibitInSourceBuild.cmake" | xargs -I file sh -c 'cat /dev/null > "file"'
%patch0 -p0
%if 0%{?centos} == 6 || 0%{?scientificlinux} == 6 || 0%{?rhel} == 505
%patch1 -p0
%endif
%if 0%{?fedora} >= 30 || 0%{?centos} == 8 || 0%{?scientificlinux} == 8 || 0%{?rhel} == 5
%patch1 -p1
%endif

%build
./configure --prefix=%{_prefix} --binary-package --enable-static-broker --enable-static-binpac
# make %{?_smp_mflags}
make

%install
rm -rf $RPM_BUILD_ROOT
%if %{defined rhel_version}
make install DESTDIR=$RPM_BUILD_ROOT
%else
%make_install
%endif
mkdir -p %{?buildroot}/opt/zeek/spool/tmp
mkdir -p %{?buildroot}/opt/zeek/logs
touch %{?buildroot}/opt/zeek/spool/zeekctl-config.sh

rm $RPM_BUILD_ROOT/%{_bindir}/bro
ln -s zeek_wrapper $RPM_BUILD_ROOT/%{_bindir}/bro
rm $RPM_BUILD_ROOT/%{_bindir}/bro-config
ln -s zeek_wrapper $RPM_BUILD_ROOT/%{_bindir}/bro-config
rm $RPM_BUILD_ROOT/%{_bindir}/bro-cut
ln -s zeek_wrapper $RPM_BUILD_ROOT/%{_bindir}/bro-cut
rm $RPM_BUILD_ROOT/%{_bindir}/broctl
ln -s zeek_wrapper $RPM_BUILD_ROOT/%{_bindir}/broctl

rm $RPM_BUILD_ROOT/%{_prefix}/share/zeekctl/scripts/zeekctl-config.sh
ln -s ../../../spool/zeekctl-config.sh $RPM_BUILD_ROOT/%{_prefix}/share/zeekctl/scripts/zeekctl-config.sh

%files

%files -n %{name}-core
%defattr(-,root,%{name},0755)
%dir %{_prefix}
%dir %{_bindir}
%dir %{_datadir}
%dir %{_datadir}/%{name}
%dir %{_mandir}
%dir %{_mandir}/man1
%dir %{_mandir}/man8
%dir %{_libdir}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_bindir}/%{name}
%{_bindir}/%{name}-wrapper
%{_bindir}/bro
%{_bindir}/%{name}-cut
%{_bindir}/bro-cut
%{_bindir}/%{name}-config
%{_bindir}/bro-config
%{_bindir}/adtrace
%{_bindir}/rst
%{_bindir}/paraglob-test
%{_datadir}/%{name}/base
%{_datadir}/%{name}/policy
%{_datadir}/%{name}/%{name}ygen
%{_mandir}/man1/%{name}-cut.1*
%{_mandir}/man8/%{name}.8*
%defattr(0664,root,%{name},2775)
%dir %{_datadir}/%{name}/site
%config %{_datadir}/%{name}/site/local.%{name}

%files -n %{name}ctl
%defattr(-,root,%{name},0755)
%dir %{_prefix}
%dir %{_bindir}
%dir %{_datadir}
%dir %{_datadir}/%{name}
%dir %{_libdir}
%dir %{_libdir}/%{name}ctl
%dir %{_mandir}
%dir %{_mandir}/man1
%dir %{_mandir}/man8
%{_bindir}/%{name}ctl
%{_bindir}/broctl
%{_bindir}/capstats
%{_bindir}/trace-summary
%{_datadir}/%{name}ctl
%{_datadir}/%{name}/%{name}ctl
%{_libdir}/broctl
%{_libdir}/%{name}ctl/*.so
%{_libdir}/%{name}ctl/*.p*
%{_libdir}/%{name}ctl/plugins
%{_libdir}/%{name}ctl/broker
%{_libdir}/%{name}ctl/ZeekControl
%{_libdir}/%{name}ctl/BroControl
%{_mandir}/man8/%{name}ctl.8*
%{_mandir}/man1/trace-summary.1*
%defattr(0664,root,%{name},2775)
%dir %{_sysconfdir}
%config %{_sysconfdir}/%{name}ctl.cfg
%config %{_sysconfdir}/networks.cfg
%config %{_sysconfdir}/node.cfg
%defattr(0664,root,%{name},2770)
%{_prefix}/spool
%{_prefix}/logs

%files -n %{name}-devel
%defattr(-,root,%{name},0755)
%dir %{_prefix}
%dir %{_bindir}
%dir %{_includedir}
%dir %{_libdir}
%dir %{_datadir}
%dir %{_datadir}/%{name}
%{_bindir}/bifcl
%{_bindir}/binpac
%{_includedir}/binpac
%{_includedir}/%{name}
%{_includedir}/paraglob
%{_libdir}/libbinpac.a
%{_libdir}/libparaglob.a
%{_datadir}/%{name}/cmake

%files -n libbroker-devel
%defattr(-,root,%{name},0755)
%dir %{_prefix}
%dir %{_includedir}
%dir %{_libdir}
%{_includedir}/broker
%{_libdir}/libbroker.a

%files -n %{name}-libcaf-devel
%defattr(-,root,%{name},0755)
%dir %{_prefix}
%dir %{_includedir}
%dir %{_libdir}
%{_includedir}/caf
%{_libdir}/libcaf_*.a

%doc CHANGES COPYING NEWS README VERSION

%changelog
* Tue Jun  9 2020 Lawrence R. Rogers <lrr@cert.org> 3.0.7-1
* Release 3.0.7-1
	Version 3.0.7-1
	See https://github.com/zeek/zeek/blob/v3.0.7/NEWS for changes

* Tue Apr 14 2020 Lawrence R. Rogers <lrr@cert.org> 3.0.5-1
* Release 3.0.5-1
	Version 3.0.5-1
	See https://github.com/zeek/zeek/blob/v3.0.5/NEWS for changes

* Mon Feb 09 2015 Johanna Amann <build@xxon.net> 2.6.3-0
* Release 2.6.3-0
	Update binpac submodule to v0.53 (Jon Siwek, Corelight)
		Fixes a signed integer overlow in array bounds checks.
	GH-435: fix null pointer deref in RPC analyzer (Jon Siwek, Corelight)
		Was possible for some failed parsing calls in
		RPC_Interpreter::DeliverRPC to set buf to a null-pointer, only for it
		to later access it when checking whether the message length appeared to be legit.

